{% extends "vega_admin/basic/base.html" %}
{% load i18n crispy_forms_tags %}

{% block title %}{% trans "Delete" %} {{ vega_verbose_name }}{% endblock%}

{% block content %}
<form action="" method="post">
    {% csrf_token %}
    <p>{% trans 'Are you sure you want to delete' %} "{{ object }}"?</p>
    <input type="submit" value="{% trans 'Confirm' %}" />
</form>
{% endblock %}