<!DOCTYPE html>
{% load staticfiles i18n %}
<html>
  <head>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}{% endblock %}</title>
    {% block meta_keywords %}<meta name="keywords" content="{% block meta_keywords_content %}{% endblock %}" />{% endblock %}
    {% block meta_description %}<meta name="description" content="{% block meta_description_content %}{% endblock %}" />{% endblock %}    
    {% block other_meta %}{% endblock %}

    {% block css %}
    <link rel="stylesheet" type="text/css" href="{% static 'badmin/bootstrap/css/bootstrap.min.css' %}" />    
    <link rel="stylesheet" type="text/css" href="{% static 'badmin/css/styles.css' %}" />  
    {% block extracss %}{% endblock %}
    {% endblock %}    

    {% block extrahead %}{% endblock %}
    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
      <script src="https://oss.maxcdn.com/libs/respond.js/1.3.0/respond.min.js"></script>
    <![endif]-->
  </head>
  <body>
    <div class="header">
       <div class="container">
          <div class="row">
             <div class="col-md-5 pull-left">
                <!-- Logo -->
                <div class="logo">
                   <h1><a href="/">Vega Admin</a></h1>
                </div>
             </div>
             <div class="clearfix"></div>
          </div>
       </div>
    </div>
    <div class="page-content">
      <div class="row">
        <div class="col-md-2">
          {% include "vega_admin/badmin/sidebar.html" %}
        </div>
        <div class="col-md-10">
          {% block messages %}
          <div class="row">
            <div class="col-md-12">
            {% if messages %}
                {% for message in messages %}
                <div class="alert alert-{% if message.tags %}{% if message.tags == 'error' %}danger{% else %}{{ message.tags }}{% endif %}{% endif %} alert-dismissible" role="alert">
                  <button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">{% trans "Close" %}</span></button>
                  {{ message }}
                </div>
                {% endfor %}
            {% endif %}  
            </div>
          </div>      
          {% endblock %}
          {% block page_content %}
          <div class="row page-content">
            <div class="col-md-12 panel-info">
              {% block all_content %}
              <div class="vega-content-box">
                {% block main_content %}{% endblock %}
              </div>
            {% endblock %}
            </div>
          </div>
          {% endblock %}
        </div>
      </div>
    </div>
    <footer>
         <div class="container">         
            <div class="copy text-center">
               &copy; Vega Admin {% trans "2018" %} - {% now "Y" %}
            </div>            
         </div>
    </footer>
    {% block js %}
    <script src="{% static 'badmin/js/jquery-2.2.4.min.js' %}"></script>
    <script src="{% static 'badmin/bootstrap/js/bootstrap.min.js' %}"></script>
    <script src="{% static 'badmin/js/custom.js' %}"></script>  
    <!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
    <script src="{% static 'badmin/js/ie10-viewport-bug-workaround.js' %}"></script>
    {% block extrajs %}{% endblock %}
    {% endblock %}
    {% block footerjs %}{% endblock %}
  </body>
</html>