{% extends "vega_admin/badmin/base.html" %}
{% load i18n django_tables2 crispy_forms_tags %}

{% block title %}{{ vega_verbose_name_plural }}{% endblock %}

{% block main_content %}
	<div class="row">
		<div class="col-md-12 content-box-info">
			<div class="content-box-header panel-heading">
				<div class="panel-title">
					{{ vega_verbose_name_plural }}
				</div>
			</div>
			<div class="content-box-large box-with-header">
				<div class="vega-content">
					<div class="table-responsive">
						{% render_table table "django_tables2/bootstrap.html" %}
					</div>
				</div>
			</div>
		</div>
	</div>
{% endblock %}

{% block footerjs %}
<script>
	$(function() {
		$('.table').stacktable({
			myClass:'stacked-table',
			headIndex: 2
		});
	});
</script>
{% endblock %}