{% extends "vega_admin/basic/base.html" %}
{% load i18n crispy_forms_tags %}

{% block title %}{% trans "Create" %} {{ vega_verbose_name }}{% endblock%}

{% block content %}
    {% crispy form %}
{% endblock %}