{% extends "vega_admin/badmin/base.html" %}
{% load i18n crispy_forms_tags %}

{% block extrahead %}
	{{form.media.css}}
{% endblock %}

{% block title %}{% trans "Create" %} {{ vega_verbose_name }}{% endblock %}

{% block main_content %}
    <div class="row">
        <div class="col-md-12 content-box-info">
            <div class="content-box-header panel-heading">
                <div class="panel-title">{% trans "Create" %} {{ vega_verbose_name }}</div>
            </div>
            <div class="content-box-large box-with-header">
                <div class="vega-content">
                    {% crispy form %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}

{% block footerjs %}
	{{form.media.js}}
{% endblock %}
