{% extends "vega_admin/badmin/base.html" %}
{% load i18n %}

{% block title %}{{ vega_object_title }} | {{ vega_verbose_name }}{% endblock %}

{% block main_content %}
    <div class="row">
        <div class="col-md-12 content-box-info">
            <div class="content-box-header panel-heading">
                <div class="panel-title">{{vega_object_title}}</div>
            </div>
            <div class="content-box-large box-with-header">
                <div class="vega-content">
                    {% for key, val in vega_object_data.items %}
                    <strong>{{key}}</strong>: {{val}} <br />
                    {% endfor %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}
